    //Reading thermophysical properties
    Info<< "Reading thermophysical properties\n" << endl;

    Info<< "Reading field T\n" << endl;
    volScalarField T
    (
        IOobject
        (
            "T",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
    );

    Info<< "Reading field p_rgh\n" << endl;
    volScalarField p_rgh
    (
        IOobject
        (
            "p_rgh",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
    );

    Info<< "Reading field U\n" << endl;
    volVectorField U
    (
        IOobject
        (
            "U",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
    );

    #include "createPhi.H"


    //Reading transport properties
    Info<< "Reading transportProperties\n" << endl;

    #include "readTransportProperties.H"


    //Calculating phase-fraction alpha
    Info<< "Calculating phase-fraction alpha\n" << endl;

    volScalarField alpha3
    (
        IOobject
        (
            "alpha3",
            runTime.timeName(),
            mesh,
            IOobject::READ_IF_PRESENT,
            IOobject::AUTO_WRITE
        ),
        max(min((T-Ts)/(Tl-Ts),scalar(1)),scalar(0))
    );

    volScalarField alpha4 ("alpha4", scalar(1) - alpha3);
    
    volScalarField Tstar("Tstar", T);


    //Creating fields for thermophysical properties
    Info<< "Creating fields for thermophysical properties\n" << endl;

    volScalarField rhok
    (
        IOobject
        (
            "rhok",
            runTime.timeName(),
            mesh
        ),
        scalar(1)-max(beta*(T-Tl),scalar(0))
    );

    volScalarField DC
    (
        IOobject
        (
            "DC",
            runTime.timeName(),
            mesh
        ),
        DCl*pow(alpha4,2)/(pow(alpha3,3)+DCs)
    );

    volScalarField lambda
    (
        IOobject
        (
            "lambda",
            runTime.timeName(),
            mesh
        ),
        alpha3*lambdal + alpha4*lambdas
    );

    volScalarField cp
    (
        IOobject
        (
            "cp",
            runTime.timeName(),
            mesh
        ),
        alpha3*cpl + alpha4*cps
    );
    cp.oldTime();

    volScalarField mu
    (
        IOobject
        (
            "mu",
            runTime.timeName(),
            mesh
        ),
        mu0*(scalar(1)-max(muk*(T-Tl),scalar(0)))
    );

    surfaceScalarField phiCp
    (
        IOobject
        (
            "phi*cp",
            runTime.timeName(),
            mesh
        ),
        phi*fvc::interpolate(cp)
    );


    //Creating fields for gravity and pressure
    Info<< "Calculating field g.h\n" << endl;

    volScalarField gh("gh", g & mesh.C());
    surfaceScalarField ghf("ghf", g & mesh.Cf());

    volScalarField p
    (
        IOobject
        (
            "p",
            runTime.timeName(),
            mesh,
            IOobject::NO_READ,
            IOobject::AUTO_WRITE
        ),
        p_rgh + rhok*gh
    );

    label pRefCell = 0;
    scalar pRefValue = 0.0;
    setRefCell
    (
        p,
        p_rgh,
        mesh.solutionDict().subDict("PIMPLE"),
        pRefCell,
        pRefValue
    );

    if (p_rgh.needReference())
    {
        p += dimensionedScalar
        (
            "p",
            p.dimensions(),
            pRefValue - getRefCellValue(p, pRefCell)
        );
    }
